<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Select</name>
    <message>
        <location filename="../Select.js" line="+216"/>
        <source>Selection Tools</source>
        <translatorcomment>--google--
Pokaż menu &quot;Zaznacz&quot;</translatorcomment>
        <translation>Narzędzia zaznaczania</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show selection tools</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż menu &quot;Zaznacz&quot;</translatorcomment>
        <translation>Wyświetla narzędzia zaznaczania</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Selection Tools Panel</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Panel narzędzi zaznaczania</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Select</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Zaznacz
&amp;Wskaźnik do zaznaczania</translatorcomment>
        <translation>&amp;Zaznaczanie</translation>
    </message>
</context>
</TS>
